==> igniteui-react-charts-18.5.1.tgz: package/esm2015/lib/NumericXAxis_combined.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { StraightNumericAxisBase } from "./StraightNumericAxisBase";
import { IScaler_$type } from "./IScaler";
import { markType, TypeRegistrar } from "igniteui-react-core";
import { HorizontalAxisLabelPanel } from "./HorizontalAxisLabelPanel";
import { ScalerParams } from "./ScalerParams";
import { Rect } from "igniteui-react-core";
import { RangeInfo } from "./RangeInfo";
import { HorizontalLogarithmicScaler } from "./HorizontalLogarithmicScaler";
import { FastHorizontalLinearScaler } from "./FastHorizontalLinearScaler";
import { isNaN_ } from "igniteui-react-core";
import { StraightNumericAxisBaseView } from "./StraightNumericAxisBaseView";
import { AxisDefaults } from "./AxisDefaults";
/**
 * @hidden
 */
export let NumericXAxis = /*@__PURE__*/ (() => {
    class NumericXAxis extends StraightNumericAxisBase {
        a4() {
            return new NumericXAxisView(this);
        }
        hs(a) {
            super.hs(a);
            this.n0 = a;
        }
        constructor() {
            super();
            this.ab = NumericXAxis.$;
            this.k0 = this.ky();
        }
        av() {
            if (this.c6) {
                return (TypeRegistrar.create('HorizontalSmartAxisLabelPanel'));
            }
            else {
                return new HorizontalAxisLabelPanel();
            }
        }
        ky() {
            let a = super.ky();
            a.b.c = (b) => {
                if ((this.az == null || this.az.visibility == 0) && this.aj != null) {
                    this.aw.bg = b;
                    if (this.az != null && (this.az.location == 4 || this.az.location == 5)) {
                        this.bi.mg();
                    }
                }
            };
            a.k = (b, c, d) => this.im(c, d, b.z, b.b, false);
            a.l = (b, c, d, e) => this.io(c, d, e, b.z);
            a.m = (b, c) => {
                let d = b.y;
                let e = new ScalerParams(0, b.aa, b.z, this.ci, d);
                return this.ej(c, e);
            };
            a.q = (b, c) => true;
            a.j = (b) => this.hq(b.t, b.n, b.z, b.a, true);
            a.e = (b) => {
                b.n = b.z.bottom;
                if (this.aj != null && this.aj.bi != null) {
                    let c = b.n;
                    let d = b.r;
                    let e = this.ie(c, d, b.aa, b.z, b.y, b.z.top, b.z.bottom);
                    c = e.p0;
                    d = e.p1;
                    b.n = c;
                    b.r = d;
                }
            };
            a.p = (b, c, d) => {
                let e = Math.round(c);
                return e >= Math.floor(b.z.left) && e <= Math.ceil(b.z.right);
            };
            return a;
        }
        ej(a, b) {
            if (this.nj != null) {
                return this.nj.p(a, b);
            }
            return this.ni.p(a, b);
        }
        em(a, b) {
            if (this.nj != null) {
                return this.nj.q(a, b);
            }
            return this.ni.q(a, b);
        }
        hn(a, b, c, d) {
            if (this.nj != null) {
                this.nj.v(a, b, c, d);
                return;
            }
            this.ni.v(a, b, c, d);
        }
        hm(a, b, c, d, e) {
            if (this.nj != null) {
                this.nj.u(a, b, c, d, e);
                return;
            }
            this.ni.u(a, b, c, d, e);
        }
        ho(a, b, c, d) {
            if (this.nj != null) {
                this.nj.j(a, b, c, d);
                return;
            }
            this.ni.j(a, b, c, d);
        }
        n1(a, b) {
            if (this.bi == null || isNaN_(a) || isNaN_(b)) {
                return;
            }
            let c = this.no(a, this);
            let d = this.no(b, this);
            if (isNaN_(c) || isNaN_(d)) {
                return;
            }
            this.bi.t3 = new Rect(0, c, this.bi.t3.y, d - c, this.bi.t3.height);
        }
        k1(a, b, c, d) {
            let e = d;
            let f = super.k1(a, b, c, d);
            let g = new ScalerParams(0, b, a, this.ch, c);
            let h = NaN;
            let i = NaN;
            if (!this.ch && b.right == 1) {
                i = this.lw;
            }
            else if (this.ch && b.left == 0) {
                h = this.lw;
            }
            if (isNaN_(h)) {
                h = this.em(e.left, g);
            }
            if (isNaN_(i)) {
                i = this.em(e.right, g);
            }
            let j = Math.min(h, i);
            let k = Math.max(h, i);
            this.l0 = j;
            this.lz = k;
            f.k.add(((() => {
                let $ret = new RangeInfo();
                $ret.d = j;
                $ret.c = k;
                $ret.b = e.width;
                return $ret;
            })()));
            return f;
        }
        h9(a) {
            super.h9(a);
            let b = this.bi != null ? this.bi.tn : Rect.empty;
            let c = !b.isEmpty ? this.kd : Rect.empty;
            let d = this.j8();
            let e = this.j7();
            let f = this.k0.c(a, c, b, d, e);
            if (f != null) {
                this.lv = f.f.m;
                this.ly = f.f.l;
            }
        }
        ip(a, b) {
            super.ip(a, b);
            if (b.height != a.height) {
                this.c1();
            }
        }
        get_a2() {
            return 0;
        }
        get a2() {
            return this.get_a2();
        }
        k3() {
            if (this.li) {
                return new HorizontalLogarithmicScaler();
            }
            switch (this.nh) {
                case 0: return new FastHorizontalLinearScaler();
                case 1: return new HorizontalLogarithmicScaler();
            }
            return null;
        }
        j$d(a, b) {
            return this.em.apply(this, arguments);
        }
        j$c(a, b) {
            return this.ej.apply(this, arguments);
        }
        j$e(a, b, c, d, e) {
            this.hm.apply(this, arguments);
        }
        j$f(a, b, c, d) {
            this.hn.apply(this, arguments);
        }
        j$g(a, b, c, d) {
            this.ho.apply(this, arguments);
        }
        get j$b() {
            return this.ch;
        }
        j$a() {
            return this.ag.apply(this, arguments);
        }
    }
    NumericXAxis.$t = /*@__PURE__*/ markType(NumericXAxis, 'NumericXAxis', StraightNumericAxisBase.$, [IScaler_$type]);
    return NumericXAxis;
})();
/**
 * @hidden
 */
export let NumericXAxisView = /*@__PURE__*/ (() => {
    class NumericXAxisView extends StraightNumericAxisBaseView {
        constructor(a) {
            super(a);
            this.bl = null;
            this.bl = a;
        }
        aj() {
            super.aj();
            this.a.jw = AxisDefaults.h;
        }
    }
    NumericXAxisView.$t = /*@__PURE__*/ markType(NumericXAxisView, 'NumericXAxisView', StraightNumericAxisBaseView.$);
    return NumericXAxisView;
})();

==> igniteui-react-charts-18.6.0.tgz: package/esm2015/lib/NumericXAxis_combined.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { StraightNumericAxisBase } from "./StraightNumericAxisBase";
import { IScaler_$type } from "./IScaler";
import { markType, TypeRegistrar } from "igniteui-react-core";
import { HorizontalAxisLabelPanel } from "./HorizontalAxisLabelPanel";
import { ScalerParams } from "./ScalerParams";
import { Rect } from "igniteui-react-core";
import { RangeInfo } from "./RangeInfo";
import { HorizontalLogarithmicScaler } from "./HorizontalLogarithmicScaler";
import { FastHorizontalLinearScaler } from "./FastHorizontalLinearScaler";
import { isNaN_ } from "igniteui-react-core";
import { StraightNumericAxisBaseView } from "./StraightNumericAxisBaseView";
import { AxisDefaults } from "./AxisDefaults";
/**
 * @hidden
 */
export let NumericXAxis = /*@__PURE__*/ (() => {
    class NumericXAxis extends StraightNumericAxisBase {
        a4() {
            return new NumericXAxisView(this);
        }
        hs(a) {
            super.hs(a);
            this.n0 = a;
        }
        constructor() {
            super();
            this.ab = NumericXAxis.$;
            this.k0 = this.ky();
        }
        av() {
            if (this.c6) {
                return (TypeRegistrar.create('HorizontalSmartAxisLabelPanel'));
            }
            else {
                return new HorizontalAxisLabelPanel();
            }
        }
        ky() {
            let a = super.ky();
            a.b.c = (b) => {
                if ((this.az == null || this.az.visibility == 0) && this.aj != null) {
                    this.aw.bg = b;
                    if (this.az != null && (this.az.location == 4 || this.az.location == 5)) {
                        this.bi.mh();
                    }
                }
            };
            a.k = (b, c, d) => this.im(c, d, b.z, b.b, false);
            a.l = (b, c, d, e) => this.io(c, d, e, b.z);
            a.m = (b, c) => {
                let d = b.y;
                let e = new ScalerParams(0, b.aa, b.z, this.ci, d);
                return this.ej(c, e);
            };
            a.q = (b, c) => true;
            a.j = (b) => this.hq(b.t, b.n, b.z, b.a, true);
            a.e = (b) => {
                b.n = b.z.bottom;
                if (this.aj != null && this.aj.bi != null) {
                    let c = b.n;
                    let d = b.r;
                    let e = this.ie(c, d, b.aa, b.z, b.y, b.z.top, b.z.bottom);
                    c = e.p0;
                    d = e.p1;
                    b.n = c;
                    b.r = d;
                }
            };
            a.p = (b, c, d) => {
                let e = Math.round(c);
                return e >= Math.floor(b.z.left) && e <= Math.ceil(b.z.right);
            };
            return a;
        }
        ej(a, b) {
            if (this.nj != null) {
                return this.nj.p(a, b);
            }
            return this.ni.p(a, b);
        }
        em(a, b) {
            if (this.nj != null) {
                return this.nj.q(a, b);
            }
            return this.ni.q(a, b);
        }
        hn(a, b, c, d) {
            if (this.nj != null) {
                this.nj.v(a, b, c, d);
                return;
            }
            this.ni.v(a, b, c, d);
        }
        hm(a, b, c, d, e) {
            if (this.nj != null) {
                this.nj.u(a, b, c, d, e);
                return;
            }
            this.ni.u(a, b, c, d, e);
        }
        ho(a, b, c, d) {
            if (this.nj != null) {
                this.nj.j(a, b, c, d);
                return;
            }
            this.ni.j(a, b, c, d);
        }
        n1(a, b) {
            if (this.bi == null || isNaN_(a) || isNaN_(b)) {
                return;
            }
            let c = this.no(a, this);
            let d = this.no(b, this);
            if (isNaN_(c) || isNaN_(d)) {
                return;
            }
            this.bi.t7 = new Rect(0, c, this.bi.t7.y, d - c, this.bi.t7.height);
        }
        k1(a, b, c, d) {
            let e = d;
            let f = super.k1(a, b, c, d);
            let g = new ScalerParams(0, b, a, this.ch, c);
            let h = NaN;
            let i = NaN;
            if (!this.ch && b.right == 1) {
                i = this.lw;
            }
            else if (this.ch && b.left == 0) {
                h = this.lw;
            }
            if (isNaN_(h)) {
                h = this.em(e.left, g);
            }
            if (isNaN_(i)) {
                i = this.em(e.right, g);
            }
            let j = Math.min(h, i);
            let k = Math.max(h, i);
            this.l0 = j;
            this.lz = k;
            f.k.add(((() => {
                let $ret = new RangeInfo();
                $ret.d = j;
                $ret.c = k;
                $ret.b = e.width;
                return $ret;
            })()));
            return f;
        }
        h9(a) {
            super.h9(a);
            let b = this.bi != null ? this.bi.tr : Rect.empty;
            let c = !b.isEmpty ? this.kd : Rect.empty;
            let d = this.j8();
            let e = this.j7();
            let f = this.k0.c(a, c, b, d, e);
            if (f != null) {
                this.lv = f.f.m;
                this.ly = f.f.l;
            }
        }
        ip(a, b) {
            super.ip(a, b);
            if (b.height != a.height) {
                this.c1();
            }
        }
        get_a2() {
            return 0;
        }
        get a2() {
            return this.get_a2();
        }
        k3() {
            if (this.li) {
                return new HorizontalLogarithmicScaler();
            }
            switch (this.nh) {
                case 0: return new FastHorizontalLinearScaler();
                case 1: return new HorizontalLogarithmicScaler();
            }
            return null;
        }
        j$d(a, b) {
            return this.em.apply(this, arguments);
        }
        j$c(a, b) {
            return this.ej.apply(this, arguments);
        }
        j$e(a, b, c, d, e) {
            this.hm.apply(this, arguments);
        }
        j$f(a, b, c, d) {
            this.hn.apply(this, arguments);
        }
        j$g(a, b, c, d) {
            this.ho.apply(this, arguments);
        }
        get j$b() {
            return this.ch;
        }
        j$a() {
            return this.ag.apply(this, arguments);
        }
    }
    NumericXAxis.$t = /*@__PURE__*/ markType(NumericXAxis, 'NumericXAxis', StraightNumericAxisBase.$, [IScaler_$type]);
    return NumericXAxis;
})();
/**
 * @hidden
 */
export let NumericXAxisView = /*@__PURE__*/ (() => {
    class NumericXAxisView extends StraightNumericAxisBaseView {
        constructor(a) {
            super(a);
            this.bo = null;
            this.bo = a;
        }
        al() {
            super.al();
            this.a.jw = AxisDefaults.h;
        }
    }
    NumericXAxisView.$t = /*@__PURE__*/ markType(NumericXAxisView, 'NumericXAxisView', StraightNumericAxisBaseView.$);
    return NumericXAxisView;
})();
